==> kie-wb-common-7.7.0.Final-project-sources.tar.gz: kie-wb-common-7.7.0.Final/kie-wb-common-forms/kie-wb-common-forms-editor/kie-wb-common-forms-editor-client/src/main/java/org/kie/workbench/common/forms/editor/client/resources/i18n/FormEditorConstants.java <==
/*
 * Copyright 2017 Red Hat, Inc. and/or its affiliates.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.kie.workbench.common.forms.editor.client.resources.i18n;

import org.jboss.errai.ui.shared.api.annotations.TranslationKey;

public interface FormEditorConstants {

    @TranslationKey(defaultValue = "")
    String NewFormDefinitionlHandlerForm = "NewFormDefinitionlHandler.form";

    @TranslationKey(defaultValue = "")
    String NewFormDefinitionlHandlerCreatingNewForm = "NewFormDefinitionlHandler.creatingNewForm";

    @TranslationKey(defaultValue = "")
    String NewFormDefinitionlHandlerSelectFormUse = "NewFormDefinitionlHandler.selectFormUse";

    @TranslationKey(defaultValue = "")
    String FormDefinitionResourceTypeFormTypeShortName = "FormDefinitionResourceType.formTypeShortName";

    @TranslationKey(defaultValue = "")
    String FormDefinitionResourceTypeFormTypeDescription = "FormDefinitionResourceType.formTypeDescription";

    @TranslationKey(defaultValue = "")
    String FormEditorPresenterTitle = "FormEditorPresenter.title";

    @TranslationKey(defaultValue = "")
    String FormEditorPresenterFormUsages = "FormEditorPresenter.formUsages";

    @TranslationKey(defaultValue = "")
    String FormEditorPresenterModelFields = "FormEditorPresenter.modelFields";

    @TranslationKey(defaultValue = "")
    String FormEditorPresenterComponentsPalette = "FormEditorPresenter.componentsPalette";

    @TranslationKey(defaultValue = "")
    String FormEditorViewImplDataObjects = "FormEditorViewImpl.dataObjects";

    @TranslationKey(defaultValue = "")
    String FormEditorViewImplDontSave = "FormEditorViewImpl.dontSave";

    @TranslationKey(defaultValue = "")
    String FormEditorViewImplPreview = "FormEditorViewImpl.preview";

    @TranslationKey(defaultValue = "")
    String FormEditorViewImplSaveBeforeRename = "FormEditorViewImpl.saveBeforeRename";

    @TranslationKey(defaultValue = "")
    String FormEditorPresenterLayoutTitle = "FormEditorPresenter.layoutTitle";

    @TranslationKey(defaultValue = "")
    String FormEditorPresenterLayoutSubTitle = "FormEditorPresenter.layoutSubTitle";

    @TranslationKey(defaultValue = "")
    String DataObjectsAdminViewImplDataObjectID = "DataObjectsAdminViewImpl.dataObjectID";

    @TranslationKey(defaultValue = "")
    String DataObjectsAdminViewImplDataObjectType = "DataObjectsAdminViewImpl.dataObjectType";

    @TranslationKey(defaultValue = "")
    String DataObjectsAdminViewImplAddDataObject = "DataObjectsAdminViewImpl.addDataObject";

    @TranslationKey(defaultValue = "")
    String DataObjectsAdminViewImplIdCannotBeEmpty = "DataObjectsAdminViewImpl.idCannotBeEmpty";

    @TranslationKey(defaultValue = "")
    String DataObjectsAdminViewImplIdAreadyExists = "DataObjectsAdminViewImpl.idAreadyExists";

    @TranslationKey(defaultValue = "")
    String DataObjectsAdminViewImplTypeCannotBeEmpty = "DataObjectsAdminViewImpl.typeCannotBeEmpty";

    @TranslationKey(defaultValue = "")
    String DataObjectsAdminViewImplEmptyDataObjectsTable = "DataObjectsAdminViewImpl.emptyDataObjectsTable";

    @TranslationKey(defaultValue = "")
    String DataObjectsAdminViewImplRemove = "DataObjectsAdminViewImpl.remove";

    @TranslationKey(defaultValue = "")
    String DataObjectsAdminViewImplDataObjectIsBoundMessage = "DataObjectsAdminViewImpl.dataObjectIsBoundMessage";

    @TranslationKey(defaultValue = "")
    String DataObjectsAdminViewImplAreYouSureRemoveDataObject = "DataObjectsAdminViewImpl.areYouSureRemoveDataObject";

    @TranslationKey(defaultValue = "")
    String FieldPropertiesRendererViewImplTitle = "FieldPropertiesRendererViewImpl.title";

    @TranslationKey(defaultValue = "")
    String FieldPropertiesRendererViewImplFieldType = "FieldPropertiesRendererViewImpl.fieldType";

    @TranslationKey(defaultValue = "")
    String FieldPropertiesRendererViewImplFieldBinding = "FieldPropertiesRendererViewImpl.fieldBinding";

    @TranslationKey(defaultValue = "Notification")
    String ChangesNotificationDisplayerTitle = "ChangesNotificationDisplayer.title";

    @TranslationKey(defaultValue = "")
    String ModelPropertyRemoved1 = "ModelProperty.removed1";

    @TranslationKey(defaultValue = "")
    String ModelPropertyRemoved2 = "ModelProperty.removed2";

    @TranslationKey(defaultValue = "")
    String ModelPropertyTypeConflict1 = "ModelProperty.typeConflict1";

    @TranslationKey(defaultValue = "")
    String ModelPropertyTypeConflict2 = "ModelProperty.typeConflict2";

    @TranslationKey(defaultValue = "")
    String NestedFormsConflictHandlerNestedForm = "NestedFormsConflictHandler.nestedForm";

    @TranslationKey(defaultValue = "")
    String NestedFormsConflictHandlerCreationForm = "NestedFormsConflictHandler.creationForm";

    @TranslationKey(defaultValue = "")
    String NestedFormsConflictHandlerEditionForm = "NestedFormsConflictHandler.editionForm";

    @TranslationKey(defaultValue = "")
    String NestedFormsConflictHandlerFix = "NestedFormsConflictHandler.fix";

    @TranslationKey(defaultValue = "Show more")
    String ConflictElementViewImplShowMore= "ConflictElementViewImpl.showMore";

    @TranslationKey(defaultValue = "Show less")
    String ConflictElementViewImplShowLess= "ConflictElementViewImpl.showLess";
}

==> kie-wb-common-7.52.0.Final-project-sources.tar.gz: kie-wb-common-7.52.0.Final/kie-wb-common-forms/kie-wb-common-forms-editor/kie-wb-common-forms-editor-client/src/main/java/org/kie/workbench/common/forms/editor/client/resources/i18n/FormEditorConstants.java <==
/*
 * Copyright 2017 Red Hat, Inc. and/or its affiliates.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.kie.workbench.common.forms.editor.client.resources.i18n;

import org.jboss.errai.ui.shared.api.annotations.TranslationKey;

public interface FormEditorConstants {

    @TranslationKey(defaultValue = "")
    String NewFormDefinitionlHandlerForm = "NewFormDefinitionlHandler.form";

    @TranslationKey(defaultValue = "")
    String NewFormDefinitionlHandlerCreatingNewForm = "NewFormDefinitionlHandler.creatingNewForm";

    @TranslationKey(defaultValue = "")
    String NewFormDefinitionlHandlerSelectFormUse = "NewFormDefinitionlHandler.selectFormUse";

    @TranslationKey(defaultValue = "")
    String FormDefinitionResourceTypeFormTypeShortName = "FormDefinitionResourceType.formTypeShortName";

    @TranslationKey(defaultValue = "")
    String FormDefinitionResourceTypeFormTypeDescription = "FormDefinitionResourceType.formTypeDescription";

    @TranslationKey(defaultValue = "")
    String FormEditorPresenterTitle = "FormEditorPresenter.title";
    
    @TranslationKey(defaultValue = "")
    String FielPropertiesEditor = "FormEditorPresenter.propertiesEditor";

    @TranslationKey(defaultValue = "")
    String FormEditorPresenterFormUsages = "FormEditorPresenter.formUsages";

    @TranslationKey(defaultValue = "")
    String FormEditorPresenterModelFields = "FormEditorPresenter.modelFields";

    @TranslationKey(defaultValue = "")
    String FormEditorPresenterComponentsPalette = "FormEditorPresenter.componentsPalette";

    @TranslationKey(defaultValue = "")
    String FormEditorViewImplDataObjects = "FormEditorViewImpl.dataObjects";

    @TranslationKey(defaultValue = "")
    String FormEditorViewImplDontSave = "FormEditorViewImpl.dontSave";

    @TranslationKey(defaultValue = "")
    String FormEditorViewImplPreview = "FormEditorViewImpl.preview";

    @TranslationKey(defaultValue = "")
    String FormEditorViewImplSaveBeforeRename = "FormEditorViewImpl.saveBeforeRename";

    @TranslationKey(defaultValue = "")
    String FormEditorPresenterLayoutTitle = "FormEditorPresenter.layoutTitle";

    @TranslationKey(defaultValue = "")
    String FormEditorPresenterLayoutSubTitle = "FormEditorPresenter.layoutSubTitle";

    @TranslationKey(defaultValue = "")
    String DataObjectsAdminViewImplDataObjectID = "DataObjectsAdminViewImpl.dataObjectID";

    @TranslationKey(defaultValue = "")
    String DataObjectsAdminViewImplDataObjectType = "DataObjectsAdminViewImpl.dataObjectType";

    @TranslationKey(defaultValue = "")
    String DataObjectsAdminViewImplAddDataObject = "DataObjectsAdminViewImpl.addDataObject";

    @TranslationKey(defaultValue = "")
    String DataObjectsAdminViewImplIdCannotBeEmpty = "DataObjectsAdminViewImpl.idCannotBeEmpty";

    @TranslationKey(defaultValue = "")
    String DataObjectsAdminViewImplIdAreadyExists = "DataObjectsAdminViewImpl.idAreadyExists";

    @TranslationKey(defaultValue = "")
    String DataObjectsAdminViewImplTypeCannotBeEmpty = "DataObjectsAdminViewImpl.typeCannotBeEmpty";

    @TranslationKey(defaultValue = "")
    String DataObjectsAdminViewImplEmptyDataObjectsTable = "DataObjectsAdminViewImpl.emptyDataObjectsTable";

    @TranslationKey(defaultValue = "")
    String DataObjectsAdminViewImplRemove = "DataObjectsAdminViewImpl.remove";

    @TranslationKey(defaultValue = "")
    String DataObjectsAdminViewImplDataObjectIsBoundMessage = "DataObjectsAdminViewImpl.dataObjectIsBoundMessage";

    @TranslationKey(defaultValue = "")
    String DataObjectsAdminViewImplAreYouSureRemoveDataObject = "DataObjectsAdminViewImpl.areYouSureRemoveDataObject";

    @TranslationKey(defaultValue = "")
    String FieldPropertiesRendererViewImplTitle = "FieldPropertiesRendererViewImpl.title";

    @TranslationKey(defaultValue = "")
    String FieldPropertiesRendererViewImplFieldType = "FieldPropertiesRendererViewImpl.fieldType";

    @TranslationKey(defaultValue = "")
    String FieldPropertiesRendererViewImplFieldBinding = "FieldPropertiesRendererViewImpl.fieldBinding";

    @TranslationKey(defaultValue = "Notification")
    String ChangesNotificationDisplayerTitle = "ChangesNotificationDisplayer.title";

    @TranslationKey(defaultValue = "")
    String ModelPropertyRemoved1 = "ModelProperty.removed1";

    @TranslationKey(defaultValue = "")
    String ModelPropertyRemoved2 = "ModelProperty.removed2";

    @TranslationKey(defaultValue = "")
    String ModelPropertyTypeConflict1 = "ModelProperty.typeConflict1";

    @TranslationKey(defaultValue = "")
    String ModelPropertyTypeConflict2 = "ModelProperty.typeConflict2";

    @TranslationKey(defaultValue = "")
    String NestedFormsConflictHandlerNestedForm = "NestedFormsConflictHandler.nestedForm";

    @TranslationKey(defaultValue = "")
    String NestedFormsConflictHandlerCreationForm = "NestedFormsConflictHandler.creationForm";

    @TranslationKey(defaultValue = "")
    String NestedFormsConflictHandlerEditionForm = "NestedFormsConflictHandler.editionForm";

    @TranslationKey(defaultValue = "")
    String NestedFormsConflictHandlerFix = "NestedFormsConflictHandler.fix";

    @TranslationKey(defaultValue = "Show more")
    String ShowMoreLabel = "showMore";

    @TranslationKey(defaultValue = "Show less")
    String ShowLessLabel = "showLess";

    @TranslationKey(defaultValue = "")
    String ErrorMessageDisplayerViewImplTitle = "ErrorMessageDisplayerViewImpl.title";

    @TranslationKey(defaultValue = "")
    String ErrorMessageDisplayerViewImplClose = "ErrorMessageDisplayerViewImpl.close";

    @TranslationKey(defaultValue = "")
    String ErrorMessageDisplayerViewImplCloseAndReview = "ErrorMessageDisplayerViewImpl.closeAndReview";

}
